
#include <linux/module.h>
#include <linux/init.h>
#include <linux/fs.h>
#include <linux/miscdevice.h>
#include <asm/uaccess.h>

#define MV_REBOOT_IOCTL_NUM   'W'

extern int force_to_reboot;

/* major number assigned to the device and device handles */
static int reboot_major;
devfs_handle_t rebootdev_handle;

static int
mv_reboot_open(struct inode *inode, struct file * file)
{
	MOD_INC_USE_COUNT;
	return 0;
}

static int
mv_reboot_close(struct inode *inode, struct file * file)
{
	MOD_DEC_USE_COUNT;
	return 0;
}

static int
mv_reboot_ioctl(struct inode *inode, struct file *file, unsigned int cmd, unsigned long arg)
{
	switch (cmd) {
		default:
		{
		    force_to_reboot=1; /* force to reboot */
		    printk("<0>""mv_reboot\n");
			break;
		}
	}

	return 0;
}
static struct file_operations mv_reboot_fops = {
	owner:		THIS_MODULE,
	open:		mv_reboot_open,
	release:	mv_reboot_close,
	ioctl:		mv_reboot_ioctl,
	};

static int __init
mv_reboot_init(void)
{
	if ((reboot_major = devfs_register_chrdev(0, "mv_reboot", &mv_reboot_fops)) < 0)
		return reboot_major;

	rebootdev_handle = devfs_register(NULL, "mv_reboot", DEVFS_FL_DEFAULT,
	                                reboot_major, 0, S_IFCHR | S_IRUGO | S_IWUGO,
	                                &mv_reboot_fops, NULL);

	return 0;
}

static void __exit
mv_reboot_exit(void)
{
	if (rebootdev_handle != NULL)
		devfs_unregister(rebootdev_handle);
	rebootdev_handle = NULL;
	devfs_unregister_chrdev(reboot_major, "mv_reboot");
}

module_init(mv_reboot_init);
module_exit(mv_reboot_exit);
